# -*- coding: utf-8 -*-
"""
------------------------------------------------------------------------------
This file is part of grepros - grep for ROS bag files and live topics.
Released under the BSD License.

@author      Erki Suurjaak
@created     31.10.2021
@modified    13.07.2023
------------------------------------------------------------------------------
"""
## @namespace grepros
__title__        = "grepros"
__version__      = "1.0.0"
__version_info__ = (1, 0, 0)
__version_date__ = "13.07.2023"

from . library import *
